#!/bin/sh
# File: e16-menu-convert.sh
# by ^thehatsrule^ for use with e16 on DSL
# to integrate fluxbox's menu entries into the e16 menu

_MENU="${HOME}/.fluxbox/menu"
INSTALL_DIR="${HOME}/.e16/menus"
SUBDIR_TITLE="menus_DSL"
INSTALL_SUBDIR="${INSTALL_DIR}/${SUBDIR_TITLE}"
INSTALL_FNAME="index.menu"
INSTALL_MENU_NAME="menus/${SUBDIR_TITLE}/${INSTALL_FNAME}"
MENU_NAME="DSL Menu"

if ! [ -e "${INSTALL_SUBDIR}" ]; then
  printf "Creating ${INSTALL_SUBDIR}...\n"
  mkdir -p "${INSTALL_SUBDIR}"
fi
if ! [ -d "${INSTALL_SUBDIR}" ]; then
  printf "Error on using ${INSTALL_SUBDIR}\n"
  exit 1
fi

pushd "${INSTALL_SUBDIR}" >/dev/null
IFS="
"

printf "Using: ${_MENU}\n"

for eachline in `cat ${_MENU}`
do
  _TITLE=`printf "${eachline}" | sed -e 's/.*\] *(//' -e 's/) *{.*//' -e 's/\\\)/)/' `
  case "${eachline}" in
      # may want to add *include* for mydsl.menu
      *begin* )
          _TITLE=`printf "${_TITLE}" | sed -e 's/) *$//'`
          printf "> "
          if [ ! -e ${INSTALL_FNAME} ]; then
            printf "\"${_TITLE}\"\n" > "${INSTALL_FNAME}"
            printf "${_TITLE}\n"
          else
            printf "Skipping, ${_TITLE} already exists\n"
          fi
          ;;
      *exec* )
          _CMD=`printf "${eachline}" | sed -e 's/.*) *{//' -e 's/}.*//' `
          _Name="${_TITLE}"
          _Exec="${_CMD}"

          printf "     "

          if [ -n "${_Name}" -a -n "${_Exec}" ]; then
            LINE_TO_ADD="\"${_Name}\" NULL exec \"${_Exec}\""
            grep "${LINE_TO_ADD}" "${INSTALL_FNAME}" >/dev/null 2>&1

            if [ $? -ne 0 ]; then
              printf "${LINE_TO_ADD}\n" >> ${INSTALL_FNAME}
              printf "${_Name} Added\n" 
            else
              printf "Skipping, ${_Name} already exists\n" 
            fi

          else
            printf "Skipping, Name or Exec not found."
          fi

          unset _Name _Exec
          ;;
      *submenu* )
          _TITLE_ORG="${_TITLE}"
          _TITLE=`printf "${_TITLE}" | sed -e 's!/!|!g' `
          if ! [ -d "${_TITLE}" ]; then
              mkdir "${_TITLE}"
          fi

          pushd "${_TITLE}" >/dev/null
          printf " -> ${_TITLE}\n"

          if ! [ -e "${INSTALL_FNAME}" ]; then
            touch "${INSTALL_FNAME}"
            if [ $? -eq 0 ]; then
              printf "\"${_TITLE_ORG}\"\n" > "${INSTALL_FNAME}"
            fi
          fi

          if ! [ -w "${INSTALL_FNAME}" -a -r "${INSTALL_FNAME}" ]; then
            printf "${INSTALL_FNAME} not rw.\n"
            exit 1
          else
            pushd ../ >/dev/null
            INSTALL_PREV_DIR=`printf $(pwd)|sed -e 's!^${INSTALL_DIR}!menus!'`
            printf "\"${_TITLE}\" NULL menu \"${INSTALL_PREV_DIR}/${_TITLE}/${INSTALL_FNAME}\"\n" >> ${INSTALL_FNAME}
            popd >/dev/null
          fi
          ;;
      *end* )
          popd >/dev/null 2>&1
          printf " <-\n"
          ;;
  esac

done

ADD_TO_FILE_MENU="${INSTALL_DIR}/file.menu"
if  [ -w "${ADD_TO_FILE_MENU}" -a -r "${ADD_TO_FILE_MENU}" ]; then
  LINE_TO_ADD_2="\"${MENU_NAME}\" NULL menu \"${INSTALL_MENU_NAME}\""
  grep "${LINE_TO_ADD_2}" "${ADD_TO_FILE_MENU}" >/dev/null

  if [ $? -eq 0 ]; then
    printf "Already added ${INSTALL_MENU_NAME} entry to ${ADD_TO_FILE_MENU}\n"
  else
    printf "Adding ${INSTALL_MENU_NAME} to ${ADD_TO_FILE_MENU}\n"

    FIRST_LINE=1
    for eachline in `cat ${ADD_TO_FILE_MENU}`
    do

      if [ ${FIRST_LINE} -eq 1 ]; then
        printf "${eachline}\n${LINE_TO_ADD_2}\n" > ${ADD_TO_FILE_MENU}
        FIRST_LINE=0
      else
        printf "${eachline}\n" >> ${ADD_TO_FILE_MENU}
      fi

    done
  fi

else
  printf "${ADD_TO_FILE_MENU} not found or rw.\n"
fi

